==> jquery-lte-1.0.3.tgz: package/src/self/methods/window.js <==
import {__ as cls, bs, _number, _string} from "../../utils/lib.js";
import { expandIcon, contractIcon, close as _close } from "../../utils/icons.js";
const { btn, df, aic, oh, oa } = bs;
let x = 6,
    y = 6;
export default (_, content = '', props) => {
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let e = { x, y, path: [] }
    let left = 0,
        right = 0,
        top = 0,
        bottom = 0;

    let { border, height, width, title, themeColor, theme } = props;
    border = _string(border, '1px solid rgba(0,0,0,.05)');
    height = _number(height, 500);
    width = _number(width, 300);
    title = _string(title);
    themeColor = typeof themeColor === 'string' ? themeColor : 'white';
    theme = _string(theme).toLowerCase() === 'windows' ? 'windows' : 'mac';

    let badge = (type = 'danger') => __(`badge rounded-pill bg-${type} p-2`, 'span').addChild(__('visually-hidden').addChild('close'));
    let el = __([oh, 'rounded shadow']).style({ height, width, transition: '10ms height, 100ms width' }).style({ border });
    let titleBar = __(['w-100 text-nowrap ps-2', oh, df, aic]).addChild(title)
    let maxinizeBtn = __('ps-0', 'button').addChild(badge('success')).attr({ title: 'Maximize' });
    let minimizeBtn = __('ps-0', 'button').addChild(badge('warning')).attr({ title: 'Minimize' });
    let closeButton = __('<button/>').addChild(badge()).attr({ title: 'Close' });
    let buttonGroup = __('btn-group').attr({ role: 'group' }).addChild([closeButton, minimizeBtn, maxinizeBtn].map(b => b.addClass([df, aic, btn])));
    let header = __([df]).addChild([buttonGroup, titleBar]).style({ height: '40px', background: themeColor, borderBottom: border });

    if (theme === 'windows') {
        header.refill([titleBar, buttonGroup]);
        buttonGroup.refill([minimizeBtn, maxinizeBtn, closeButton]).addClass('ms-auto');
        closeButton.addClass('ps-0').refill(_(_close()).addClass('text-secondary'))
            .on('mouseenter', () => closeButton.children().get(0).addClass('text-danger'))
            .on('mouseleave', () => closeButton.children().get(0).removeClass('text-danger'))
        maxinizeBtn.refill(_(expandIcon()).addClass('text-secondary'));
        minimizeBtn.removeClass('ps-0').refill(_(contractIcon()).addClass('text-secondary'));
    }
    let body = __([oa, 'mini-scrollbar text-break']).style({ height: 'calc(100% - 40px)', background: 'white' }).addChild(content);
    typeof content === 'string' && body.addClass('p-2')
    el.addChild([header, body]);
    el.mountAt(e, { height, width, movable: header });

    const minimize = () => {
        if (!el.attr('expanded')) return;
        el.style({
            height: height + 'px',
            width: width + 'px',
            left,
            right,
            top,
            bottom
        }).removeAttribute('expanded');
    };
    const maximize = () => {
        if (el.attr('expanded')) return;
        left = el.getStyle('left');
        right = el.getStyle('right');
        top = el.getStyle('top');
        bottom = el.getStyle('bottom');
        el.style({
            height: '100%',
            width: '100%',
            top: '0',
            bottom: '0',
            right: '0',
            left: '0'
        }).attr({ 'expanded': 'true' })
    };

    const close = () => {
        el.drop();
        x -= 20;
        y -= 20;
    };
    const moveTo = (x = 0, y = 0) => { el.style({ left: x + 'px', top: y + 'px' }) };
    const resizeTo = (_width = width, _height = height) => {
        el.style({ width: _width + 'px', height: _height + 'px' });
        width = _width;
        height = _height;
    };

    minimizeBtn.on('click', minimize);
    maxinizeBtn.on('click', maximize)
    closeButton.on('click', close);
    header.on('dblclick', e => {
        if (e.path.some(p => [minimizeBtn.plain(0), maxinizeBtn.plain(0), closeButton.plain(0)].includes(p))) return;
        if (el.attr('expanded'))
            minimize();
        else
            maximize()
    })
    x += 20;
    y += 20;
    return { minimize, maximize, close, moveTo, resizeTo }
}

==> jquery-lte-1.1.0.tgz: package/src/self/methods/window.js <==
import {__ as cls, bs, _number, _string} from "../../utils/lib.js";
import { expandIcon, contractIcon, close as _close } from "../../utils/icons.js";
const { btn, df, aic, oh, oa } = bs;
let x = 6,
    y = 6;
export default (_, content = '', props) => {
    let running = true;
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let callbacks = {minimized: null, maximized: null, closed: null};

    let e = { x, y, path: [] }
    let left = 0,
        right = 0,
        top = 0,
        bottom = 0;

    let { border, height, width, title, themeColor, theme, movable = true, resizable = true } = props;
    border = _string(border, '1px solid rgba(0,0,0,.05)');
    height = _number(height, 500);
    width = _number(width, 300);
    title = _string(title);
    themeColor = typeof themeColor === 'string' ? themeColor : 'white';
    theme = _string(theme).toLowerCase() === 'windows' ? 'windows' : 'mac';

    let badge = (type = 'danger') => __(`badge rounded-pill bg-${type} p-2`, 'span').addChild(__('visually-hidden').addChild('close'));
    let el = __([oh, 'rounded shadow']).style({ height, width, transition: '10ms height, 100ms width' }).style({ border });
    let titleBar = __(['w-100 text-nowrap ps-2', oh, df, aic]).addChild(title)
    let maxinizeBtn = __('ps-0', 'button').addChild(badge('success')).attr({ title: 'Maximize' });
    let minimizeBtn = __('ps-0', 'button').addChild(badge('warning')).attr({ title: 'Minimize' });
    let closeButton = __('<button/>').addChild(badge()).attr({ title: 'Close' });
    let buttonGroup = __('btn-group').attr({ role: 'group' }).addChild([closeButton, minimizeBtn, maxinizeBtn].map(b => b.addClass([df, aic, btn])));
    let header = __([df]).addChild([buttonGroup, titleBar]).style({ height: '40px', background: themeColor, borderBottom: border });

    if (theme === 'windows') {
        header.refill([titleBar, buttonGroup]);
        buttonGroup.refill([minimizeBtn, maxinizeBtn, closeButton]).addClass('ms-auto');
        closeButton.addClass('ps-0').refill(_(_close()).addClass('text-secondary'))
            .on('mouseenter', () => closeButton.children().get(0).addClass('text-danger'))
            .on('mouseleave', () => closeButton.children().get(0).removeClass('text-danger'))
        maxinizeBtn.refill(_(expandIcon()).addClass('text-secondary'));
        minimizeBtn.removeClass('ps-0').refill(_(contractIcon()).addClass('text-secondary'));
    }
    let body = __([oa, 'mini-scrollbar text-break']).style({ height: 'calc(100% - 40px)', background: 'white' }).addChild(content);
    typeof content === 'string' && body.addClass('p-2')
    el.addChild([header, body]);
    el.mountAt(e, { height, width, movable: movable ? header: false });

    const minimize = () => {
        if (!el.attr('expanded') || running === false || !resizable) return;
        el.style({
            height: height + 'px',
            width: width + 'px',
            left,
            right,
            top,
            bottom
        }).removeAttribute('expanded');

        callbacks.minimized?.call();
    };
    const maximize = () => {
        if (el.attr('expanded') || running === false || !resizable) return;
        left = el.getStyle('left');
        right = el.getStyle('right');
        top = el.getStyle('top');
        bottom = el.getStyle('bottom');
        el.style({
            height: '100%',
            width: '100%',
            top: '0',
            bottom: '0',
            right: '0',
            left: '0'
        }).attr({ 'expanded': 'true' });
        callbacks.maximized?.call();
    };

    const close = () => {
        if(running === false) return;
        el.drop();
        x -= 20;
        y -= 20;
        callbacks.closed?.call();
        running = false;
    };
    const moveTo = (x = 0, y = 0) => { 
        if(running === false || !movable) return;
        el.style({ left: x + 'px', top: y + 'px' });
    };
    const resizeTo = (_width = width, _height = height) => {
        if(running === false || !resizable) return;
        el.style({ width: _width + 'px', height: _height + 'px' });
        width = _width;
        height = _height;
    };
    const on = (event, callback) => {
        if(typeof callback !== 'function' || typeof event !== 'string') return;
          event.trim().split(' ').map(e => {
              callbacks[e] = callback;
          });
    }

    minimizeBtn.on('click', minimize);
    maxinizeBtn.on('click', maximize)
    closeButton.on('click', close);
    header.on('dblclick', e => {
        if (e.path.some(p => [minimizeBtn.plain(0), maxinizeBtn.plain(0), closeButton.plain(0)].includes(p))) return;
        if (el.attr('expanded'))
            minimize();
        else
            maximize()
    });
    x += 20;
    y += 20;
    return { 
        minimize(){
            minimize();
        }, 
        maximize(){
            maximize()
        }, 
        close(){
            close()
        }, 
        /**
         * 
         * @param {Number} x 
         * @param {Number} y 
         */
        moveTo(x, y){
            moveTo(x, y);
        }, 
        /**
         * 
         * @param {Number} newWidth 
         * @param {Number} newHeight 
         */
        resizeTo(newWidth, newHeight){
            resizeTo(newWidth, newHeight);
        }, 
        /**
         * 
         * @param {'resized' | 'closed' | 'minimized' | 'maximized' | 'moved'} event 
         * @param {Function} callback 
         */
        on(event, callback){
            on(event, callback)
        } }
}
